BodyFatSample class

Body fat percentage sample.

Constructors

BodyFatSample({required double percentage, required DateTime timestamp, required String source, String device = ''})
const
BodyFatSample.fromMap(Map<String, dynamic> m)
factory

Properties

device String
final
hashCode int
The hash code for this object.
no setterinherited
percentage double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited