HeightSample class

Height sample in meters and cm.

Constructors

HeightSample({required double meters, double? cm, required DateTime timestamp, required String source, String device = ''})
const
HeightSample.fromMap(Map<String, dynamic> m)
factory

Properties

centimeters double
no setter
cm double?
final
device String
final
hashCode int
The hash code for this object.
no setterinherited
meters double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited