WeightSample class
Weight sample in kg and lbs.
Constructors
- WeightSample({required double kg, double? lbs, required DateTime timestamp, required String source, String device = ''})
-
const
-
WeightSample.fromMap(Map<
String, dynamic> m) -
factory
Properties
- device → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kg → double
-
final
- lbs → double?
-
final
- poundsValue → double
-
lbs value — computed from kg if not provided by native.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited