ExerciseSegment class

Constructors

ExerciseSegment({required String type, required DateTime start, required DateTime end, required int repetitions})
const
ExerciseSegment.fromMap(Map<String, dynamic> m)
factory

Properties

end DateTime
final
hashCode int
The hash code for this object.
no setterinherited
repetitions int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited