ExerciseSession class

An exercise/workout session with optional lap and segment data.

Constructors

ExerciseSession({required String exerciseType, required DateTime start, required DateTime end, required int durationMinutes, required String source, String title = '', String notes = '', String device = '', List<ExerciseLap> laps = const [], List<ExerciseSegment> segments = const []})
const
ExerciseSession.fromMap(Map<String, dynamic> m)
factory

Properties

device String
final
durationMinutes int
final
end DateTime
final
exerciseType String
final
hashCode int
The hash code for this object.
no setterinherited
laps List<ExerciseLap>
final
notes String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<ExerciseSegment>
final
source String
final
start DateTime
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited