HydrationRecord class

A hydration record.

Constructors

HydrationRecord({required double volumeLiters, required DateTime start, required DateTime end, required String source})
const
HydrationRecord.fromMap(Map<String, dynamic> m)
factory

Properties

end DateTime
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
start DateTime
final
volumeLiters double
final
volumeMl double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited