SleepBreakdown class

Aggregated sleep stage durations for a session.

Constructors

SleepBreakdown({required int deepMinutes, required int remMinutes, required int lightMinutes, required int awakeMinutes, required int asleepMinutes})
const
SleepBreakdown.fromMap(Map<String, dynamic> m)
factory
SleepBreakdown.fromStages(List<SleepStage> stages)
Compute breakdown from a list of stages (fallback when native doesn't provide a pre-computed breakdown).
factory

Properties

asleepMinutes int
final
awakeMinutes int
final
deepMinutes int
final
hashCode int
The hash code for this object.
no setterinherited
lightMinutes int
final
remMinutes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalSleepMinutes int
Total actual sleep time (excludes awake).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited