SleepStage class

Individual sleep stage within a session.

Constructors

SleepStage({required String stage, required DateTime start, required DateTime end, required int durationMinutes})
const
SleepStage.fromMap(Map<String, dynamic> m)
factory

Properties

durationMinutes int
final
end DateTime
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage String
One of: deep, rem, light, awake, asleep, outOfBed, unknown.
final
start DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited