BloodGlucoseSample class

Blood glucose reading with meal context.

Constructors

BloodGlucoseSample({required double mmolPerL, required double mgPerDl, required DateTime timestamp, required String source, String mealType = '', String specimenSource = '', String relationToMeal = '', String device = ''})
const
BloodGlucoseSample.fromMap(Map<String, dynamic> m)
factory

Properties

device String
final
hashCode int
The hash code for this object.
no setterinherited
mealType String
final
mgPerDl double
final
mmolPerL double
final
relationToMeal String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
specimenSource String
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited