BloodPressureSample class

Blood pressure reading — systolic and diastolic always paired.

Constructors

BloodPressureSample({required double systolicMmhg, required double diastolicMmhg, required DateTime timestamp, required String source, String bodyPosition = '', String measurementLocation = '', String device = ''})
const
BloodPressureSample.fromMap(Map<String, dynamic> m)
factory

Properties

bodyPosition String
final
device String
final
diastolicMmhg double
final
hashCode int
The hash code for this object.
no setterinherited
measurementLocation String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
systolicMmhg double
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited