HrvSample class

Heart rate variability sample.

Platform difference:

  • Android Health Connect returns RMSSD (ms)
  • iOS HealthKit returns SDNN (ms) These are different statistical measures — do not compare directly.

Constructors

HrvSample({double? rmssdMs, double? sdnnMs, required DateTime timestamp, required String source, String device = ''})
const
HrvSample.fromMap(Map<String, dynamic> m)
factory

Properties

device String
final
hashCode int
The hash code for this object.
no setterinherited
rmssdMs double?
RMSSD in milliseconds (Android). Null on iOS.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdnnMs double?
SDNN in milliseconds (iOS). Null on Android.
final
source String
final
timestamp DateTime
final
valueMs double
The platform-available HRV value in ms, regardless of metric type.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited