AggregatedActivity class
Aggregated activity data returned by HealthKitWrapper.aggregateActivity.
All values are deduplicated by the native SDK's aggregate API — prefer this over manually summing sample records.
Constructors
-
AggregatedActivity({required int steps, required double distanceKm, required double floors, required double activeCaloriesKcal, required double totalCaloriesKcal, required List<
String> dataOrigins}) -
const
- AggregatedActivity.empty()
-
factory
-
AggregatedActivity.fromMap(Map<
String, dynamic> m) -
factory
Properties
- activeCaloriesKcal → double
-
Always in kilocalories — never raw calories.
final
-
dataOrigins
→ List<
String> -
Package names (Android) or bundle identifiers (iOS) of source apps.
final
- distanceKm → double
-
final
- floors → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- steps → int
-
final
- totalCaloriesKcal → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited