ObserverUpdate class
An update event from the health data observer.
On Android this is driven by Health Connect's ChangesToken polling. On iOS this is driven by HealthKit's push-based HKObserverQuery.
Constructors
Properties
-
deletedTypes
→ List<
String> -
final
- hasChanges → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
insertedTypes
→ List<
String> -
final
- observerId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited