HeartRateSample class

Heart rate sample — individual BPM reading with source.

Constructors

HeartRateSample({required int bpm, required DateTime timestamp, required String source, String device = ''})
const
HeartRateSample.fromMap(Map<String, dynamic> m)
factory

Properties

bpm int
final
device String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited