Vo2MaxSample class

VO2 max in ml/min/kg.

Constructors

Vo2MaxSample({required double vo2Max, required DateTime timestamp, required String source, String measurementMethod = '', String device = ''})
const
Vo2MaxSample.fromMap(Map<String, dynamic> m)
factory

Properties

device String
final
hashCode int
The hash code for this object.
no setterinherited
measurementMethod String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
timestamp DateTime
final
vo2Max double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited